@@ -111,10 +111,15 @@ Profile ID (from your GA account) you want to use.
 
 Arrayref to list of desired dimensions.
 
+  $req->dimensions([qw(pagePath)]);
+
 =item metrics
 
 Arrayref to list of desired metrics.
 
+  $req->metrics([qw(visitors newVisits visits bounces timeOnSite entrances
+      pageviews uniquePageviews timeOnPage exits)]);
+
 =item segment
 
 String containing desired segment.
@@ -123,6 +128,8 @@ String containing desired segment.
 
 Arrayref to list of desired filters.
 
+  $req->filters(['browser==Firefox']);
+
 =item sort
 
 Specification of column sorting; either a single name (string) or a list
